from django.db import models
from django.utils.six import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _
from fluent_contents.models import ContentItem


@python_2_unicode_compatible
class PrivateNotesItem(ContentItem):
    """
    Private notes
    """
    date_created = models.DateTimeField(_("Created at"), auto_now_add=True)
    date_modified = models.DateTimeField(_("Last modified at"), auto_now=True)
    notes = models.TextField(_("Notes"), help_text=_("These notes are only visible for you as administrator"))

    class Meta:
        verbose_name = _("Private note")
        verbose_name_plural = _("Private notes")

    def __str__(self):
        return self.notes



from django.contrib import admin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _
from fluent_pages.adminui.utils import get_page_admin_url
from .models import PrivateNotesItem


@admin.register(PrivateNotesItem)
class PrivateNotesAdmin(admin.ModelAdmin):
    """
    Admin for private notes.
    """
    #date_hierarchy = 'date_created'
    readonly_fields = ('date_created', 'date_modified', 'parent_field')
    fieldsets = (
        (None, {
            'fields': ('notes',),
        }),
        (_("Metadata"), {
            'fields': ('date_created', 'date_modified', 'parent_field'),
        }),
    )

    class Media:
        css = {
            'screen': (
                'admin/fluentcms_privatenotes/privatenotes.css',
            ),
        }

    def parent_field(self, object):
        parent = object.parent
        url = get_page_admin_url(parent)
        return format_html('<a href="{0}">{1} ({2})</a>', url, parent, parent.default_url)

    parent_field.short_description = _("Page")



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fluent_contents', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrivateNotesItem',
            fields=[
                ('contentitem_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='fluent_contents.ContentItem')),
                ('date_created', models.DateTimeField(verbose_name='Created at', auto_now_add=True)),
                ('date_modified',models.DateTimeField(verbose_name='Last modified at', auto_now=True)),
                ('notes', models.TextField(help_text='These notes are only visible for you as administrator', verbose_name='Notes')),
            ],
            options={
                'db_table': 'contentitem_fluentcms_privatenotes_privatenotesitem',
                'verbose_name': 'Private note',
                'verbose_name_plural': 'Private notes',
            },
            bases=('fluent_contents.contentitem',),
        ),
    ]



from django.test import TestCase
from fluent_contents.tests.factories import create_content_item
from fluent_contents.tests.utils import render_content_items
from fluentcms_privatenotes.models import PrivateNotesItem


class PrivateNotesTests(TestCase):
    """
    Testing private notes
    """

    def test_no_output(self):
        """
        Test that the item doens't produce output.
        """
        item = create_content_item(PrivateNotesItem, notes="HIDDEN-NOTES!")
        self.assertEqual(render_content_items([item]).html, u'')



from django.utils.translation import ugettext_lazy as _
from fluent_contents.extensions import ContentPlugin, plugin_pool
from .models import PrivateNotesItem


@plugin_pool.register
class PrivateNotesPlugin(ContentPlugin):
    """
    Plugin to place notes on a page.
    """
    model = PrivateNotesItem
    category = _("Internal")
    admin_form_template = ContentPlugin.ADMIN_TEMPLATE_WITHOUT_LABELS

    def render(self, request, instance, **kwargs):
        return u''

    class Media:
        css = {
            'screen': (
                'admin/fluentcms_privatenotes/privatenotes.css',
            ),
        }
